@@ -28,13 +28,14 @@ test_that("manual", {
   set.seed(99)
   hc <- ssd_hc(dists, ci = TRUE, nboot = 10)
   expect_is(hc, "tbl_df")
-  expect_identical(colnames(hc), c("percent", "est", "se", "lcl", "ucl", "dist"))
+  expect_identical(colnames(hc), c("percent", "est", "se", "lcl", "ucl", "dist", "wt"))
   expect_identical(hc$percent, 5)
   expect_equal(hc$est, 1.2504293469908)
   expect_equal(hc$se, 0.631776851773594)
   expect_equal(hc$lcl, 0.775249435219941)
   expect_equal(hc$ucl, 2.60353105288968)
   expect_equal(hc$dist, "average") 
+  expect_equal(hc$wt, 1)
   
   dists <- ssd_gof(dists)
   expect_is(dists, "tbl_df")
